﻿#region License Information

/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */

#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using HeuristicLab.MainForm;
using HeuristicLab.Optimization;
using HeuristicLab.Optimizer;

using MenuItem = HeuristicLab.MainForm.WindowsForms.MenuItem;

namespace HeuristicLab.Problems.DataAnalysis.Views {
  public abstract class OptimizeDataAnalysisRunsMenuItem : MenuItem, IOptimizerUserInterfaceItemProvider {
    public override string Name {
      get { return "Optimize Runs"; }
    }
    public override IEnumerable<string> Structure {
      get { return new string[] { "&Data Analysis" }; }
    }
    public override int Position {
      get { return 5400; }
    }
    public override string ToolTipText {
      get {
        return "This command tries to optimize each run by performing a pruning and a constant optimization step on the solution models.";
      }
    }
    protected override void OnToolStripItemSet(EventArgs e) {
      ToolStripItem.Enabled = false;
    }
    protected RunCollection runCollection;

    protected override void OnActiveViewChanged(object sender, EventArgs e) {
      IContentView activeView = MainFormManager.MainForm.ActiveView as IContentView;
      if (activeView == null) {
        ToolStripItem.Enabled = false;
        return;
      }

      var content = activeView.Content;
      runCollection = content as RunCollection;
      if (runCollection == null && content is IOptimizer)
        runCollection = ((IOptimizer)content).Runs;

      if (runCollection == null) {
        ToolStripItem.Enabled = false;
        return;
      }

      ToolStripItem.Enabled = runCollection.Any(run => run.Results.ContainsKey("Best training solution"));
    }
  }
}
